@@ -57,6 +57,9 @@ func renderKuryr(conf *operv1.NetworkSpec, bootstrapResult *bootstrap.BootstrapR
 	data.Data["PoolMinPorts"] = c.PoolMinPorts
 	data.Data["PoolBatchPorts"] = c.PoolBatchPorts
 
+	// deploy or not kuryr-admission-controller depending on double listeners support
+	data.Data["AdmissionController"] = !b.OctaviaMultipleListeners
+
 	// kuryr-daemon DaemonSet data
 	data.Data["DaemonEnableProbes"] = true
 	data.Data["DaemonProbesPort"] = c.DaemonProbesPort
